@@ -1,6 +1,6 @@
 import logging
-from dataclasses import dataclass
-from typing import List, Union
+from dataclasses import dataclass, field
+from typing import List, Union, Optional
 
 from brain_brew.commands.run_recipe.build_task import TopLevelBuildTask
 from brain_brew.configuration.representation_base import RepresentationBase
@@ -25,19 +25,32 @@ class GenerateGuidsInCsvs(TopLevelBuildTask):
         return f'''\
             source: any(str(), list(str()))
             columns: any(str(), list(str()))
+            delimiter: str(required=False)
         '''
 
     @dataclass
     class Representation(RepresentationBase):
         source: Union[str, List[str]]
         columns: Union[str, List[str]]
+        delimiter: Optional[str] = field(default=None)
+
+        def encode_filter(self, key, value):
+            if not super().encode_filter(key, value):
+                return False
+            if key == 'delimiter' and all(CsvFile.delimiter_matches_file_type(value, f) for f in single_item_to_list(self.source)):
+                return False
+            return True
 
     @classmethod
     def from_repr(cls, data: Union[Representation, dict]):
         rep: cls.Representation = data if isinstance(data, cls.Representation) else cls.Representation.from_dict(data)
+        csv_files = [CsvFile.create_or_get(csv) for csv in single_item_to_list(rep.source)]
+        for c in csv_files:
+            c.set_delimiter(rep.delimiter)
+            c.read_file()
         return cls(
             rep=rep,
-            sources=[CsvFile.create_or_get(csv) for csv in single_item_to_list(rep.source)],
+            sources=csv_files,
             columns=rep.columns
         )
 
@@ -52,8 +65,9 @@ class GenerateGuidsInCsvs(TopLevelBuildTask):
 
         # Make sure the columns exist on all
         for source in self.sources:
-            if any([c not in source.column_headers for c in self.columns]):
-                errors.append(f"Csv '{source.file_location}' does not contain all the specified columns.")
+            missing = [c for c in self.columns if c not in source.column_headers]
+            if any(missing):
+                errors.append(f"Csv '{source.file_location}' does not contain all the specified columns: {missing}")
 
         if errors:
             raise KeyError(errors)
